/*
 * Test program for C libvpd
 */

#include <libvpd-2/vpdretriever.h>
#include <stdio.h>

#define DIR "/var/lib/lsvpd"
#define FILE "vpd.db"

void print_component_vpd( struct component *root )
{
	struct component *child;
		
	printf( "id:       %s\n", root->id->dataValue );
	printf( "loc code: %s\n", root->physicalLocation->dataValue );
	
	child = root->children;
	while( child )
	{
		print_component_vpd( child );
		child = child->next;
	}
}

void print_system_vpd( struct system *root )
{
	struct component *child;
	
	printf( "id:       %s\n", root->id->dataValue );
	printf( "loc code: %s\n", root->locationCode->dataValue );
	
	child = root->children;
	while( child )
	{
		print_component_vpd( child );
		child = child->next;
	}
}

int main( int argc, char **argv )
{
	struct vpdretriever *env;
	struct system *vpd;
	
	env = new_vpdretriever( DIR, FILE );
	if( !env )
	{
		printf( "Error building new VPD retriever.\n" );
		return 1;
	}
	
	vpd = get_component_tree( env );
	if( !vpd )
	{
		printf( "Error getting system VPD.\n" );
		free_vpdretriever( env );
		return 1;
	}
	
	print_system_vpd( vpd );
	free_system( vpd );
	free_vpdretriever( env );
	return 0;
}
